from . import simulationio

def export3d_solid_mesh(data_container_array, meshing_package = None, output_path = None, package_location = None, surface_mesh_face_labels_array_path = None, feature_phases_array_path = None, feature_euler_angles_array_path = None, feature_centroid_array_path = None, refine_mesh = None, max_radius_edge_ratio = None, min_dihedral_angle = None, limit_tetrahedra_volume = None, max_tetrahedra_volume = None, optimization_level = None, include_holes_using_phase_id = None, phase_id = None, tet_data_container_name = None, vertex_attribute_matrix_name = None, cell_attribute_matrix_name = None, gmsh_stl_file_name = None, mesh_file_format = None, netgen_stl_file_name = None, mesh_size = None, observer = None) -> int:
  """Pythonic interface to Export3dSolidMesh Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    meshing_package (int): Sets the "MeshingPackage" filter property
    output_path (QString): Sets the "outputPath" filter property
    package_location (QString): Sets the "PackageLocation" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    feature_centroid_array_path (DataArrayPath): Sets the "FeatureCentroidArrayPath" filter property
    refine_mesh (bool): Sets the "RefineMesh" filter property
    max_radius_edge_ratio (float): Sets the "MaxRadiusEdgeRatio" filter property
    min_dihedral_angle (float): Sets the "MinDihedralAngle" filter property
    limit_tetrahedra_volume (bool): Sets the "LimitTetrahedraVolume" filter property
    max_tetrahedra_volume (float): Sets the "MaxTetrahedraVolume" filter property
    optimization_level (int): Sets the "OptimizationLevel" filter property
    include_holes_using_phase_id (bool): Sets the "IncludeHolesUsingPhaseID" filter property
    phase_id (int): Sets the "PhaseID" filter property
    tet_data_container_name (QString): Sets the "TetDataContainerName" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    gmsh_stl_file_name (QString): Sets the "GmshSTLFileName" filter property
    mesh_file_format (int): Sets the "MeshFileFormat" filter property
    netgen_stl_file_name (QString): Sets the "NetgenSTLFileName" filter property
    mesh_size (int): Sets the "MeshSize" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.Export3dSolidMesh()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if meshing_package is not None:
    filter.MeshingPackage = meshing_package
  if output_path is not None:
    filter.outputPath = output_path
  if package_location is not None:
    filter.PackageLocation = package_location
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if feature_centroid_array_path is not None:
    filter.FeatureCentroidArrayPath = feature_centroid_array_path
  if refine_mesh is not None:
    filter.RefineMesh = refine_mesh
  if max_radius_edge_ratio is not None:
    filter.MaxRadiusEdgeRatio = max_radius_edge_ratio
  if min_dihedral_angle is not None:
    filter.MinDihedralAngle = min_dihedral_angle
  if limit_tetrahedra_volume is not None:
    filter.LimitTetrahedraVolume = limit_tetrahedra_volume
  if max_tetrahedra_volume is not None:
    filter.MaxTetrahedraVolume = max_tetrahedra_volume
  if optimization_level is not None:
    filter.OptimizationLevel = optimization_level
  if include_holes_using_phase_id is not None:
    filter.IncludeHolesUsingPhaseID = include_holes_using_phase_id
  if phase_id is not None:
    filter.PhaseID = phase_id
  if tet_data_container_name is not None:
    filter.TetDataContainerName = tet_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if gmsh_stl_file_name is not None:
    filter.GmshSTLFileName = gmsh_stl_file_name
  if mesh_file_format is not None:
    filter.MeshFileFormat = mesh_file_format
  if netgen_stl_file_name is not None:
    filter.NetgenSTLFileName = netgen_stl_file_name
  if mesh_size is not None:
    filter.MeshSize = mesh_size
  filter.execute()
  return filter.ErrorCode

def import_fea_data(data_container_array, fea_package = None, odb_name = None, odb_file_path = None, abq_python_command = None, instance_name = None, step = None, frame_number = None, bsam_input_file = None, deform_input_file = None, deform_point_track_input_file = None, time_series_bundle_name = None, import_single_time_step = None, single_time_step_value = None, selected_time_array_name = None, selected_time_step_array_name = None, selected_point_num_array_name = None, selected_x_coord_array_name = None, selected_y_coord_array_name = None, data_array_list = None, data_container_name = None, vertex_attribute_matrix_name = None, cell_attribute_matrix_name = None, observer = None) -> int:
  """Pythonic interface to ImportFEAData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    fea_package (int): Sets the "FEAPackage" filter property
    odb_name (QString): Sets the "odbName" filter property
    odb_file_path (QString): Sets the "odbFilePath" filter property
    abq_python_command (QString): Sets the "ABQPythonCommand" filter property
    instance_name (QString): Sets the "InstanceName" filter property
    step (QString): Sets the "Step" filter property
    frame_number (int): Sets the "FrameNumber" filter property
    bsam_input_file (QString): Sets the "BSAMInputFile" filter property
    deform_input_file (QString): Sets the "DEFORMInputFile" filter property
    deform_point_track_input_file (QString): Sets the "DEFORMPointTrackInputFile" filter property
    time_series_bundle_name (QString): Sets the "TimeSeriesBundleName" filter property
    import_single_time_step (bool): Sets the "ImportSingleTimeStep" filter property
    single_time_step_value (int): Sets the "SingleTimeStepValue" filter property
    selected_time_array_name (QString): Sets the "SelectedTimeArrayName" filter property
    selected_time_step_array_name (QString): Sets the "SelectedTimeStepArrayName" filter property
    selected_point_num_array_name (QString): Sets the "SelectedPointNumArrayName" filter property
    selected_x_coord_array_name (QString): Sets the "SelectedXCoordArrayName" filter property
    selected_y_coord_array_name (QString): Sets the "SelectedYCoordArrayName" filter property
    data_array_list (QStringList): Sets the "DataArrayList" filter property
    data_container_name (QString): Sets the "DataContainerName" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.ImportFEAData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fea_package is not None:
    filter.FEAPackage = fea_package
  if odb_name is not None:
    filter.odbName = odb_name
  if odb_file_path is not None:
    filter.odbFilePath = odb_file_path
  if abq_python_command is not None:
    filter.ABQPythonCommand = abq_python_command
  if instance_name is not None:
    filter.InstanceName = instance_name
  if step is not None:
    filter.Step = step
  if frame_number is not None:
    filter.FrameNumber = frame_number
  if bsam_input_file is not None:
    filter.BSAMInputFile = bsam_input_file
  if deform_input_file is not None:
    filter.DEFORMInputFile = deform_input_file
  if deform_point_track_input_file is not None:
    filter.DEFORMPointTrackInputFile = deform_point_track_input_file
  if time_series_bundle_name is not None:
    filter.TimeSeriesBundleName = time_series_bundle_name
  if import_single_time_step is not None:
    filter.ImportSingleTimeStep = import_single_time_step
  if single_time_step_value is not None:
    filter.SingleTimeStepValue = single_time_step_value
  if selected_time_array_name is not None:
    filter.SelectedTimeArrayName = selected_time_array_name
  if selected_time_step_array_name is not None:
    filter.SelectedTimeStepArrayName = selected_time_step_array_name
  if selected_point_num_array_name is not None:
    filter.SelectedPointNumArrayName = selected_point_num_array_name
  if selected_x_coord_array_name is not None:
    filter.SelectedXCoordArrayName = selected_x_coord_array_name
  if selected_y_coord_array_name is not None:
    filter.SelectedYCoordArrayName = selected_y_coord_array_name
  if data_array_list is not None:
    filter.DataArrayList = data_array_list
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  filter.execute()
  return filter.ErrorCode

def export_lammps_file(data_container_array, lammps_file = None, atom_feature_labels_path = None, observer = None) -> int:
  """Pythonic interface to ExportLAMMPSFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    lammps_file (QString): Sets the "LammpsFile" filter property
    atom_feature_labels_path (DataArrayPath): Sets the "AtomFeatureLabelsPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.ExportLAMMPSFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if lammps_file is not None:
    filter.LammpsFile = lammps_file
  if atom_feature_labels_path is not None:
    filter.AtomFeatureLabelsPath = atom_feature_labels_path
  filter.execute()
  return filter.ErrorCode

def export_damask_files(data_container_array, data_format = None, output_path = None, geometry_file_name = None, homogenization_index = None, feature_ids_array_path = None, cell_phases_array_path = None, cell_euler_angles_array_path = None, compress_geom_file = None, observer = None) -> int:
  """Pythonic interface to ExportDAMASKFiles Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_format (int): Sets the "DataFormat" filter property
    output_path (QString): Sets the "OutputPath" filter property
    geometry_file_name (QString): Sets the "GeometryFileName" filter property
    homogenization_index (int): Sets the "HomogenizationIndex" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    compress_geom_file (bool): Sets the "CompressGeomFile" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.ExportDAMASKFiles()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_format is not None:
    filter.DataFormat = data_format
  if output_path is not None:
    filter.OutputPath = output_path
  if geometry_file_name is not None:
    filter.GeometryFileName = geometry_file_name
  if homogenization_index is not None:
    filter.HomogenizationIndex = homogenization_index
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if compress_geom_file is not None:
    filter.CompressGeomFile = compress_geom_file
  filter.execute()
  return filter.ErrorCode

def export_on_scale_table_file(data_container_array, output_path = None, output_file_prefix = None, pzflex_feature_ids_array_path = None, num_keypoints = None, phase_names_array_path = None, observer = None) -> int:
  """Pythonic interface to ExportOnScaleTableFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_path (QString): Sets the "OutputPath" filter property
    output_file_prefix (QString): Sets the "OutputFilePrefix" filter property
    pzflex_feature_ids_array_path (DataArrayPath): Sets the "PzflexFeatureIdsArrayPath" filter property
    num_keypoints (IntVec3Type): Sets the "NumKeypoints" filter property
    phase_names_array_path (DataArrayPath): Sets the "PhaseNamesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.ExportOnScaleTableFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if output_file_prefix is not None:
    filter.OutputFilePrefix = output_file_prefix
  if pzflex_feature_ids_array_path is not None:
    filter.PzflexFeatureIdsArrayPath = pzflex_feature_ids_array_path
  if num_keypoints is not None:
    filter.NumKeypoints = num_keypoints
  if phase_names_array_path is not None:
    filter.PhaseNamesArrayPath = phase_names_array_path
  filter.execute()
  return filter.ErrorCode

def create_abaqus_file(data_container_array, output_path = None, output_file_prefix = None, job_name = None, num_depvar = None, num_user_out_var = None, mat_const = None, abq_feature_ids_array_path = None, cell_euler_angles_array_path = None, cell_phases_array_path = None, observer = None) -> int:
  """Pythonic interface to CreateAbaqusFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_path (QString): Sets the "OutputPath" filter property
    output_file_prefix (QString): Sets the "OutputFilePrefix" filter property
    job_name (QString): Sets the "JobName" filter property
    num_depvar (int): Sets the "NumDepvar" filter property
    num_user_out_var (int): Sets the "NumUserOutVar" filter property
    mat_const (DynamicTableData): Sets the "MatConst" filter property
    abq_feature_ids_array_path (DataArrayPath): Sets the "AbqFeatureIdsArrayPath" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.CreateAbaqusFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if output_file_prefix is not None:
    filter.OutputFilePrefix = output_file_prefix
  if job_name is not None:
    filter.JobName = job_name
  if num_depvar is not None:
    filter.NumDepvar = num_depvar
  if num_user_out_var is not None:
    filter.NumUserOutVar = num_user_out_var
  if mat_const is not None:
    filter.MatConst = mat_const
  if abq_feature_ids_array_path is not None:
    filter.AbqFeatureIdsArrayPath = abq_feature_ids_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  filter.execute()
  return filter.ErrorCode

def create_bsam_file(data_container_array, output_path = None, output_file_prefix = None, num_clusters = None, observer = None) -> int:
  """Pythonic interface to CreateBsamFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_path (QString): Sets the "OutputPath" filter property
    output_file_prefix (QString): Sets the "OutputFilePrefix" filter property
    num_clusters (int): Sets the "NumClusters" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.CreateBsamFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if output_file_prefix is not None:
    filter.OutputFilePrefix = output_file_prefix
  if num_clusters is not None:
    filter.NumClusters = num_clusters
  filter.execute()
  return filter.ErrorCode

def export_multi_on_scale_table_file(data_container_array, output_path = None, data_container_prefix = None, matrix_name = None, array_name = None, selected_arrays = None, num_keypoints = None, phase_names_array_path = None, observer = None) -> int:
  """Pythonic interface to ExportMultiOnScaleTableFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_path (QString): Sets the "OutputPath" filter property
    data_container_prefix (QString): Sets the "DataContainerPrefix" filter property
    matrix_name (QString): Sets the "MatrixName" filter property
    array_name (QString): Sets the "ArrayName" filter property
    selected_arrays (QString): Sets the "SelectedArrays" filter property
    num_keypoints (IntVec3Type): Sets the "NumKeypoints" filter property
    phase_names_array_path (DataArrayPath): Sets the "PhaseNamesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.ExportMultiOnScaleTableFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if data_container_prefix is not None:
    filter.DataContainerPrefix = data_container_prefix
  if matrix_name is not None:
    filter.MatrixName = matrix_name
  if array_name is not None:
    filter.ArrayName = array_name
  if selected_arrays is not None:
    filter.SelectedArrays = selected_arrays
  if num_keypoints is not None:
    filter.NumKeypoints = num_keypoints
  if phase_names_array_path is not None:
    filter.PhaseNamesArrayPath = phase_names_array_path
  filter.execute()
  return filter.ErrorCode

def import_on_scale_table_file(data_container_array, volume_data_container_name = None, cell_attribute_matrix_name = None, phase_attribute_matrix_name = None, material_name_array_name = None, rect_grid_geometry_desc = None, input_file = None, origin = None, spacing = None, feature_ids_array_name = None, observer = None) -> int:
  """Pythonic interface to ImportOnScaleTableFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    volume_data_container_name (DataArrayPath): Sets the "VolumeDataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    phase_attribute_matrix_name (QString): Sets the "PhaseAttributeMatrixName" filter property
    material_name_array_name (QString): Sets the "MaterialNameArrayName" filter property
    rect_grid_geometry_desc (QString): Sets the "RectGridGeometryDesc" filter property
    input_file (QString): Sets the "InputFile" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.ImportOnScaleTableFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if phase_attribute_matrix_name is not None:
    filter.PhaseAttributeMatrixName = phase_attribute_matrix_name
  if material_name_array_name is not None:
    filter.MaterialNameArrayName = material_name_array_name
  if rect_grid_geometry_desc is not None:
    filter.RectGridGeometryDesc = rect_grid_geometry_desc
  if input_file is not None:
    filter.InputFile = input_file
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def import_delam_data(data_container_array, csdgm_file = None, bvid_std_out_file = None, interface_thickness = None, data_container_path = None, observer = None) -> int:
  """Pythonic interface to ImportDelamData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    csdgm_file (QString): Sets the "CSDGMFile" filter property
    bvid_std_out_file (QString): Sets the "BvidStdOutFile" filter property
    interface_thickness (float): Sets the "InterfaceThickness" filter property
    data_container_path (DataArrayPath): Sets the "DataContainerPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = simulationio.ImportDelamData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if csdgm_file is not None:
    filter.CSDGMFile = csdgm_file
  if bvid_std_out_file is not None:
    filter.BvidStdOutFile = bvid_std_out_file
  if interface_thickness is not None:
    filter.InterfaceThickness = interface_thickness
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  filter.execute()
  return filter.ErrorCode

